pub struct WgpuStorage { /* private fields */ }Expand description
Buffer storage for wgpu.
Implementations
Sourceimpl WgpuStorage
Keeps actual wgpu buffer references in a hashmap with ids as key.
impl WgpuStorage
Keeps actual wgpu buffer references in a hashmap with ids as key.