pub struct WgpuRuntime<Compiler = AutoCompiler> { /* private fields */ }Expand description
Runtime that uses the wgpu crate with the wgsl compiler. This is used in the Wgpu backend.
For advanced configuration, use init_setup to pass in runtime options or to select a
specific graphics API.